==========================
``psyclone.domain.gocean``
==========================

.. automodule:: psyclone.domain.gocean

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.domain.gocean.gocean_constants
   psyclone.domain.gocean.transformations

.. currentmodule:: psyclone.domain.gocean


Classes
=======

- :py:class:`GOceanConstants`:
  This class stores all GOcean constants.


.. autoclass:: GOceanConstants
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: GOceanConstants
      :parts: 1
